Win32 only: Enabling STRICT to fix a VC++ compile warning.
[privoxy.git] / project.h
index 581d3ae..0b7b75e 100644 (file)
--- a/project.h
+++ b/project.h
@@ -1,6 +1,6 @@
 #ifndef PROJECT_H_INCLUDED
 #define PROJECT_H_INCLUDED
-#define PROJECT_H_VERSION "$Id: project.h,v 1.56 2002/03/13 20:27:30 oes Exp $"
+#define PROJECT_H_VERSION "$Id: project.h,v 1.62 2002/03/26 22:48:49 swa Exp $"
 /*********************************************************************
  *
  * File        :  $Source: /cvsroot/ijbswa/current/project.h,v $
@@ -10,7 +10,7 @@
  *                (though it does declare some macros).
  *
  * Copyright   :  Written by and Copyright (C) 2001 the SourceForge
- *                IJBSWA team.  http://ijbswa.sourceforge.net
+ *                Privoxy team. http://www.privoxy.org/
  *
  *                Based on the Internet Junkbuster originally written
  *                by and Copyright (C) 1997 Anonymous Coders and
  *
  * Revisions   :
  *    $Log: project.h,v $
+ *    Revision 1.62  2002/03/26 22:48:49  swa
+ *    new homepage url
+ *
+ *    Revision 1.61  2002/03/26 22:29:55  swa
+ *    we have a new homepage!
+ *
+ *    Revision 1.60  2002/03/24 15:52:17  jongfoster
+ *    Changing CGI URL prefixes for new name
+ *
+ *    Revision 1.59  2002/03/24 15:23:33  jongfoster
+ *    Name changes
+ *
+ *    Revision 1.58  2002/03/24 13:25:43  swa
+ *    name change related issues
+ *
+ *    Revision 1.57  2002/03/16 20:28:34  oes
+ *    Added descriptions to the filters so users will know what they select in the cgi editor
+ *
  *    Revision 1.56  2002/03/13 20:27:30  oes
  *    Fixing bug with CT_TABOO
  *
  * I don't want to have to #include all this just for the declaration
  * of SOCKET.  However, it looks like we have to...
  */
+#ifndef STRICT
+#define STRICT
+#endif
 #include <windows.h>
 #endif
 
@@ -756,7 +777,7 @@ struct url_actions
 #define CSP_FLAG_TOGGLED_ON 0x20 /* Set if we are toggled on (FEATURE_TOGGLE) */
 
 /*
* The state of a JunkBuster processing thread.
  */
 struct client_state
 {
@@ -855,7 +876,7 @@ struct cgi_dispatcher
 
 
 /*
* A data file used by JunkBuster.  Kept in a linked list.
  */
 struct file_list
 {
@@ -1044,7 +1065,7 @@ struct configuration_spec
 #define SZ(X)  (sizeof(X) / sizeof(*X))
 
 #ifdef FEATURE_FORCE_LOAD
-#define FORCE_PREFIX "/IJB-FORCE-LOAD"
+#define FORCE_PREFIX "/PRIVOXY-FORCE"
 #endif /* def FEATURE_FORCE_LOAD */
 
 #ifdef FEATURE_NO_GIFS
@@ -1055,7 +1076,7 @@ struct configuration_spec
 
 
 /* Hardwired URLs */
-#define HOME_PAGE_URL       "http://ijbswa.sourceforge.net"
+#define HOME_PAGE_URL       "http://www.privoxy.org"
 #define REDIRECT_URL        HOME_PAGE_URL "/redirect.php?v=" VERSION "&to="
 
 /*
@@ -1067,9 +1088,9 @@ struct configuration_spec
  * 2) CGI_SITE_2_PATH must not end with /, one will be added automatically.
  * 3) CGI_SITE_2_PATH must start with /, unless it is the empty string.
  */
-#define CGI_SITE_1_HOST "i.j.b"
-#define CGI_SITE_2_HOST "ijbswa.sourceforge.net"
-#define CGI_SITE_2_PATH "/config"
+#define CGI_SITE_1_HOST "p.p"
+#define CGI_SITE_2_HOST "config.privoxy.org"
+#define CGI_SITE_2_PATH ""
 
 /*
  * The prefix for CGI pages.  Written out in generated HTML.
@@ -1081,7 +1102,7 @@ struct configuration_spec
 /* HTTP snipplets */
 static const char CSUCCEED[] =
    "HTTP/1.0 200 Connection established\n"
-   "Proxy-Agent: IJ/" VERSION "\r\n\r\n";
+   "Proxy-Agent: Privoxy/" VERSION "\r\n\r\n";
 
 static const char CHEADER[] =
    "HTTP/1.0 400 Invalid header received from browser\r\n\r\n";
@@ -756,7 +777,7 @@ struct url_actions
 
 /*
- * The state of a JunkBuster processing thread.
+ * The state of a Privoxy processing thread.
  */
 struct client_state
@@ -855,7 +876,7 @@ struct cgi_dispatcher
 
 /*
- * A data file used by JunkBuster.  Kept in a linked list.
+ * A data file used by Privoxy.  Kept in a linked list.
  */
 struct file_list